from .config import notify


State = type("State", (), {})


class TickEvent:
    ''' tick event '''
    pass


class StartEvent:
    ''' push start button '''
    pass


class StopEvent:
    ''' push stop button '''
    pass


class ShortEvent:
    ''' push short pause button '''
    pass


class LongEvent:
    ''' push long pause button '''
    pass


class InitState(State):
    pass


class SelectState(State):
    pass


class TomatoState(State):

    def __init__(self, stime):
        """
        stime - state start time
        """
        self.stime = stime

    def get_time(self):
        return self.stime


class ShortState(State):

    def __init__(self, stime):
        self.stime = stime

    def get_time(self):
        return self.stime


class LongState(State):

    def __init__(self, stime):
        self.stime = stime

    def get_time(self):
        return self.stime


class LogicFMS():
    def __init__(self):
        self.state = InitState()
        self.tomacco = 0

    def remining_time(self, event, stime):
        if isinstance(event, TickEvent):
            count = stime - self.state.get_time()
            return count

    def set_state(self, state):
        self.state = state

    def next_state(self, event, stime):
        if isinstance(self.state, InitState):
            if event == StartEvent:
                self.state = TomatoState(stime)
            elif isinstance(event, ShortEvent):
                self.state = ShortState(stime)
            elif isinstance(event, LongEvent):
                self.state = LongState(stime)

        elif isinstance(self.state, TomatoState):
            if isinstance(event, TickEvent):
                if self.tomat <= int(stime - self.state.get_time()):
                    self.state = SelectState()
                    self.tomacco += 1
                    notify('Count Tomacco Stop')
            elif isinstance(event, StopEvent):
                self.state = InitState()
            elif isinstance(event, LongEvent):
                self.state = LongState(stime)
            elif isinstance(event, ShortEvent):
                self.state = ShortState(stime)

        elif isinstance(self.state, SelectState):
            if isinstance(event, ShortEvent):
                self.state = ShortState(stime)
            elif isinstance(event, LongEvent):
                self.state = LongState(stime)

        elif isinstance(self.state, ShortState):
            if isinstance(event, TickEvent):
                if self.spause <= int(stime - self.state.get_time()):
                    self.state = InitState()
                    notify('Short Pause Stop')
            elif isinstance(event, StopEvent):
                self.state = InitState()
            elif isinstance(event, LongEvent):
                self.state = LongState(stime)
            elif isinstance(event, StartEvent):
                self.state = TomatoState(stime)

        elif isinstance(self.state, LongState):
            if isinstance(event, TickEvent):
                if self.lpause <= int(stime - self.state.get_time()):
                    self.state = InitState()
                    notify('Long Pause Stop')
                    self.tomacco = 0
            elif isinstance(event, StopEvent):
                self.state = InitState()
                self.tomacco = 0
            elif isinstance(event, ShortEvent):
                self.state = ShortState(stime)
            elif isinstance(event, StartEvent):
                self.state = TomatoState(stime)



import os
import subprocess
from .config import read_conf
from PyQt4 import QtGui

def image_tray(image):
    root = __file__
    if os.path.islink(root):
        root = os.path.realpath(root)
    img_path = os.path.dirname(os.path.dirname(os.path.abspath(root))) + '/images/'
    return QtGui.QIcon(img_path + image)


def run(when):
    command = read_conf('run_commands', when, True)
    cmd_list = command.split()
    if cmd_list:
        subprocess.Popen(cmd_list)



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'form.ui'
#
# Created: Fri Feb  6 15:26:43 2015
#      by: PyQt5 UI code generator 5.4
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(360, 201)
        self.centralwidget = QtGui.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.horizontalLayout_2 = QtGui.QHBoxLayout(self.centralwidget)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.horizontalLayout = QtGui.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.lcd = QtGui.QLCDNumber(self.centralwidget)
        self.lcd.setObjectName("lcd")
        self.horizontalLayout.addWidget(self.lcd)
        self.verticalLayout = QtGui.QVBoxLayout()
        self.verticalLayout.setContentsMargins(-1, 0, -1, -1)
        self.verticalLayout.setObjectName("verticalLayout")
        self.btn_start = QtGui.QPushButton(self.centralwidget)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btn_start.sizePolicy().hasHeightForWidth())
        self.btn_start.setSizePolicy(sizePolicy)
        self.btn_start.setObjectName("btn_start")
        self.verticalLayout.addWidget(self.btn_start)
        self.btn_stop = QtGui.QPushButton(self.centralwidget)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btn_stop.sizePolicy().hasHeightForWidth())
        self.btn_stop.setSizePolicy(sizePolicy)
        self.btn_stop.setObjectName("btn_stop")
        self.verticalLayout.addWidget(self.btn_stop)
        self.btn_spause = QtGui.QPushButton(self.centralwidget)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(30)
        sizePolicy.setHeightForWidth(self.btn_spause.sizePolicy().hasHeightForWidth())
        self.btn_spause.setSizePolicy(sizePolicy)
        self.btn_spause.setObjectName("btn_spause")
        self.verticalLayout.addWidget(self.btn_spause)
        self.btn_lpause = QtGui.QPushButton(self.centralwidget)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(30)
        sizePolicy.setHeightForWidth(self.btn_lpause.sizePolicy().hasHeightForWidth())
        self.btn_lpause.setSizePolicy(sizePolicy)
        self.btn_lpause.setObjectName("btn_lpause")
        self.verticalLayout.addWidget(self.btn_lpause)
        spacerItem = QtGui.QSpacerItem(20, 40, QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem)
        self.horizontalLayout.addLayout(self.verticalLayout)
        self.horizontalLayout.setStretch(0, 10)
        self.horizontalLayout_2.addLayout(self.horizontalLayout)
        MainWindow.setCentralWidget(self.centralwidget)
        self.status_bar = QtGui.QStatusBar(MainWindow)
        self.status_bar.setObjectName("status_bar")
        MainWindow.setStatusBar(self.status_bar)

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.btn_start.setText(_translate("MainWindow", "Start \n"
"Tomacco"))
        self.btn_stop.setText(_translate("MainWindow", "Stop \n"
"Tomacco"))
        self.btn_spause.setText(_translate("MainWindow", "Short Pause"))
        self.btn_lpause.setText(_translate("MainWindow", "Long Pause"))




from setuptools import setup, find_packages

setup(
    name='tomacco',
    version='0.4.2',
    author='axce1',
    author_email='axce1.github@gmail.com',
    packages=find_packages(),
    include_package_data=True,
    description='Pomodoro Technique time',
    long_description='The Pomodoro Technique is a time management method developed by Francesco Cirillo in the late 1980s',
    platforms='Linux',
    url='http://github.com/axce1/tomacco',
    license='WTFPL',
    classifiers=[
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
    ],
    entry_points={
        'console_scripts':
            ['tomacco=tomacco.main:main',
             'tomacco_cli=tomacco.tomacco_cli']
    }
)



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ui/dialog.ui'
#
# Created by: PyQt4 UI code generator 4.11.4
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName(_fromUtf8("Dialog"))
        Dialog.resize(178, 275)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Dialog.sizePolicy().hasHeightForWidth())
        Dialog.setSizePolicy(sizePolicy)
        self.ttime = QtGui.QLabel(Dialog)
        self.ttime.setGeometry(QtCore.QRect(10, 10, 101, 16))
        self.ttime.setObjectName(_fromUtf8("ttime"))
        self.lptime = QtGui.QLabel(Dialog)
        self.lptime.setGeometry(QtCore.QRect(10, 40, 101, 16))
        self.lptime.setObjectName(_fromUtf8("lptime"))
        self.sptime = QtGui.QLabel(Dialog)
        self.sptime.setGeometry(QtCore.QRect(10, 70, 101, 16))
        self.sptime.setObjectName(_fromUtf8("sptime"))
        self.spinTomat = QtGui.QSpinBox(Dialog)
        self.spinTomat.setGeometry(QtCore.QRect(128, 10, 41, 22))
        self.spinTomat.setMinimum(1)
        self.spinTomat.setObjectName(_fromUtf8("spinTomat"))
        self.spinShort = QtGui.QSpinBox(Dialog)
        self.spinShort.setGeometry(QtCore.QRect(128, 70, 41, 22))
        self.spinShort.setMinimum(1)
        self.spinShort.setObjectName(_fromUtf8("spinShort"))
        self.spinLong = QtGui.QSpinBox(Dialog)
        self.spinLong.setGeometry(QtCore.QRect(128, 40, 41, 22))
        self.spinLong.setMinimum(1)
        self.spinLong.setObjectName(_fromUtf8("spinLong"))
        self.btnCnl = QtGui.QPushButton(Dialog)
        self.btnCnl.setGeometry(QtCore.QRect(10, 240, 75, 26))
        self.btnCnl.setObjectName(_fromUtf8("btnCnl"))
        self.btnOk = QtGui.QPushButton(Dialog)
        self.btnOk.setGeometry(QtCore.QRect(90, 240, 75, 26))
        self.btnOk.setObjectName(_fromUtf8("btnOk"))
        self.run_label = QtGui.QLabel(Dialog)
        self.run_label.setGeometry(QtCore.QRect(10, 100, 91, 16))
        self.run_label.setObjectName(_fromUtf8("run_label"))
        self.start_run = QtGui.QCheckBox(Dialog)
        self.start_run.setGeometry(QtCore.QRect(10, 120, 121, 20))
        self.start_run.setObjectName(_fromUtf8("start_run"))
        self.finish_run = QtGui.QCheckBox(Dialog)
        self.finish_run.setGeometry(QtCore.QRect(10, 170, 131, 20))
        self.finish_run.setObjectName(_fromUtf8("finish_run"))
        self.start_edit = QtGui.QLineEdit(Dialog)
        self.start_edit.setEnabled(False)
        self.start_edit.setGeometry(QtCore.QRect(30, 140, 141, 22))
        self.start_edit.setObjectName(_fromUtf8("start_edit"))
        self.finish_edit = QtGui.QLineEdit(Dialog)
        self.finish_edit.setEnabled(False)
        self.finish_edit.setGeometry(QtCore.QRect(30, 200, 141, 22))
        self.finish_edit.setObjectName(_fromUtf8("finish_edit"))

        self.retranslateUi(Dialog)
        QtCore.QObject.connect(self.start_run, QtCore.SIGNAL(_fromUtf8("toggled(bool)")), self.start_edit.setEnabled)
        QtCore.QObject.connect(self.finish_run, QtCore.SIGNAL(_fromUtf8("toggled(bool)")), self.finish_edit.setEnabled)
        QtCore.QMetaObject.connectSlotsByName(Dialog)
        Dialog.setTabOrder(self.spinTomat, self.spinLong)
        Dialog.setTabOrder(self.spinLong, self.spinShort)
        Dialog.setTabOrder(self.spinShort, self.btnOk)
        Dialog.setTabOrder(self.btnOk, self.btnCnl)

    def retranslateUi(self, Dialog):
        Dialog.setWindowTitle(_translate("Dialog", "Dialog", None))
        self.ttime.setText(_translate("Dialog", "Tomato Time", None))
        self.lptime.setText(_translate("Dialog", "Long Pause Time", None))
        self.sptime.setText(_translate("Dialog", "Short Pause Time", None))
        self.btnCnl.setText(_translate("Dialog", "Cancel", None))
        self.btnOk.setText(_translate("Dialog", "Ok", None))
        self.run_label.setText(_translate("Dialog", "Run commands", None))
        self.start_run.setText(_translate("Dialog", "with start pomidor", None))
        self.finish_run.setText(_translate("Dialog", "when finish pomidor", None))

